@@ -4,8 +4,9 @@ from .EditSearchPropertyHandler import makeSearchPropertyHandler
 from .SettingPropertyHandler import makeSettingPropertyHandler
 
 
-def makeAdminBackendHandlers(tupleObservable: TupleDataObservableHandler,
-                             dbSessionCreator):
+def makeAdminBackendHandlers(
+    tupleObservable: TupleDataObservableHandler, dbSessionCreator
+):
     yield makeSearchPropertyHandler(tupleObservable, dbSessionCreator)
     yield makeSearchObjectTypeHandler(tupleObservable, dbSessionCreator)
 
