@@ -1,7 +1,8 @@
 import logging
 
-from peek_abstract_chunked_index.private.server.controller.ACIProcessorStatusControllerABC import \
-    ACIProcessorStatusControllerABC
+from peek_abstract_chunked_index.private.server.controller.ACIProcessorStatusControllerABC import (
+    ACIProcessorStatusControllerABC,
+)
 from peek_core_search._private.tuples.AdminStatusTuple import AdminStatusTuple
 
 logger = logging.getLogger(__name__)
