@@ -4,11 +4,12 @@ from vortex.Tuple import Tuple, addTupleType, TupleField
 
 @addTupleType
 class SearchResultDetailTuple(Tuple):
-    """ Search Result Detail Tuple
+    """Search Result Detail Tuple
 
     This tuple represents the details of a search result.
     """
-    __tupleType__ = searchTuplePrefix + 'SearchResultDetailTuple'
+
+    __tupleType__ = searchTuplePrefix + "SearchResultDetailTuple"
 
     #:  The name of the detail
     name: str = TupleField()
